@@ -1,13 +1,10 @@
-use crate::{
-    store::{PortMap, Store},
-    svec,
-};
+use crate::{docker::PortMap, store::Store, svec};
 
 pub struct Cassandra;
 
 impl Store for Cassandra {
     fn name(&self) -> String {
-        "oomplay-cassandra".to_string()
+        "cassandra".to_string()
     }
 
     fn image(&self) -> String {
@@ -18,7 +15,7 @@ impl Store for Cassandra {
         vec![PortMap::Tcp(9042, 29042)]
     }
 
-    fn init_cmd(&self) -> Vec<String> {
+    fn reset_cmd(&self) -> Vec<String> {
         svec![
             "cqlsh",
             "-e",
