@@ -1,13 +1,10 @@
-use crate::{
-    store::{PortMap, Store},
-    svec,
-};
+use crate::{docker::PortMap, store::Store, svec};
 
 pub struct DynamoDB;
 
 impl Store for DynamoDB {
     fn name(&self) -> String {
-        "oomplay-localstack-dynamodb".to_string()
+        "localstack-dynamodb".to_string()
     }
 
     fn image(&self) -> String {
@@ -22,7 +19,7 @@ impl Store for DynamoDB {
         vec![PortMap::Tcp(4566, 24566)]
     }
 
-    fn init_cmd(&self) -> Vec<String> {
+    fn reset_cmd(&self) -> Vec<String> {
         svec![
             "bash",
             "-c",
