@@ -1,13 +1,10 @@
-use crate::{
-    store::{PortMap, Store},
-    svec,
-};
+use crate::{docker::PortMap, store::Store, svec};
 
-pub struct PostgreSQL;
+pub struct Postgres;
 
-impl Store for PostgreSQL {
+impl Store for Postgres {
     fn name(&self) -> String {
-        "oomplay-postgres".to_string()
+        "postgres".to_string()
     }
 
     fn image(&self) -> String {
@@ -26,7 +23,7 @@ impl Store for PostgreSQL {
         vec![PortMap::Tcp(5432, 25432)]
     }
 
-    fn init_cmd(&self) -> Vec<String> {
+    fn reset_cmd(&self) -> Vec<String> {
         svec![
             "sh",
             "-c",
